@@ -7,7 +7,16 @@ from fpql.ql_conventions import *
 from fpql.termstructure import *
 
 def sample_piecewise(value_date):
-    # Curve data
+    rates, depo_setting, parrates, par_setting = sample_curveinfo()
+
+    return curve_piecewise(value_date, 
+                            depo_setting, 
+                            rates, 
+                            par_setting, 
+                            parrates)
+
+
+def sample_curveinfo():
     depo_rates = [
         {"tenor": "1M", "rate": 2.00},
         {"tenor": "2M", "rate": 2.05}, 
@@ -55,7 +64,29 @@ def sample_piecewise(value_date):
     }
     par_setting = BondSetting(**par_sett)
 
-    return curve_piecewise(value_date, depo_setting, rates, par_setting, parrates)
+    return rates, depo_setting, parrates, par_setting
+
+
+def sample_spreadinfo():
+    spread_rates = [
+        {"tenor": "1M", "rate": 0.4},
+        {"tenor": "2M", "rate": 0.45}, 
+        {"tenor": "3M", "rate": 0.5},
+        {"tenor": "6M", "rate": 0.55},
+        {"tenor": "1Y", "rate": 0.6},
+        {"tenor": "2Y", "rate": 0.65}, 
+        {"tenor": "3Y", "rate": 0.75},
+        {"tenor": "5Y", "rate": 0.85},
+        {"tenor": "7Y", "rate": 0.95},
+        {"tenor": "10Y", "rate": 1.1},
+        {"tenor": "20Y", "rate": 1.3},
+        {"tenor": "30Y", "rate": 1.5}
+    ]
+    rates = []
+    for depo_rate in spread_rates:
+        rate = Rate(**depo_rate)
+        rates.append(rate)
+    return rates
 
 
 #NOTE: changing business_day to no_adjustment will not give
@@ -73,10 +104,10 @@ def sample_bondinfo():
 
     setting = BondSetting(**bondsetting)
 
-    bonddata = {"issue_date": "2021-07-29", 
-                "maturity": "2026-07-29", 
+    bonddata = {"issue_date": "2021-01-05", 
+                "maturity": "2026-01-05", 
                 "settings": setting, 
-                "coupon": 5.0,
+                "coupon": 5.00,
                 "face_value": 10_000_000
                 }
     thebond = FixedRateBond(**bonddata)
